.. :changelog:

History
-------

1.1.0 (2019-10-7)
+++++++++++++++++

* Removed non used utilities
* Added StatusMixin
* Added SearchQuerySetMixin and SearchFilter
* Added ActionSerializersMixin
* Updated UploadToDir

1.0.0 (2018-10-2)
+++++++++++++++++

* Updated UploadToDir with ``prefix`` param.
* Contrib package with Django Rest Framework utils.

1.0a2 (2017-2-21)
+++++++++++++++++

* Added generators module.
* Added admin widget fot ForeignKeys

1.0a1 (2017-2-20)
+++++++++++++++++

* First release on PyPI.
